==> lxqt-config_0.14.1.orig.tar.xz: lxqt-config-0.14.1/liblxqt-config-cursor/translations/lxqt-config-cursor_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Configuració del tema del ratolí de LXQt</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Seleccioneu el tema de cursors que vulgueu utilitzar (passeu el cursor per sobre de la vista prèvia per a provar el cursor). &lt;b&gt;Després d&apos;aquest canvi cal que es reiniciï la sessió de LXQt&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instal·la un tema nou...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>Sup&amp;rimeix el tema</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="212"/>
        <source>XCurTheme error</source>
        <translation>Error XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="213"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>No podeu suprimir el tema actiu!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt no ha pogut trobar cap tema de cursors. En lloc seu s&apos;utilitzarà el tema de cursors predeterminat de X11. LXQt ha buscat als directoris següents:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Mostra...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
</context>
</TS>

==> lxqt-config_0.16.1.orig.tar.xz: lxqt-config-0.16.1/liblxqt-config-cursor/translations/lxqt-config-cursor_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Configuració del tema del ratolí de LXQt</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="46"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Seleccioneu el tema de cursors que vulgueu utilitzar (passeu el cursor per sobre de la vista prèvia per a provar el cursor). &lt;b&gt;Després d&apos;aquest canvi cal que es reiniciï la sessió de LXQt&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="23"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instal·la un tema nou...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="91"/>
        <source>&amp;Remove Theme</source>
        <translation>Sup&amp;rimeix el tema</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="233"/>
        <source>XCurTheme error</source>
        <translation>Error XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="234"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>No podeu suprimir el tema actiu!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt no ha pogut trobar cap tema de cursors. En lloc seu s&apos;utilitzarà el tema de cursors predeterminat de X11. LXQt ha buscat als directoris següents:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Mostra...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
</context>
</TS>
